@@ -52,9 +52,6 @@ static gboolean events_enabled = FALSE;
  */
 static int response_and_hold = -1;
 
-#define CALL_STATUS_INDEX 3
-#define CALL_SETUP_INDEX 4
-#define LAST_DIAL_INDEX  7
 static struct indicator dummy_indicators[] =
 {
 	{ "battchg",	"0-5",	5 },
@@ -64,7 +61,6 @@ static struct indicator dummy_indicators[] =
 	{ "callsetup",	"0-3",	0 },
 	{ "callheld",	"0-2",	0 },
 	{ "roam",	"0,1",	0 },
-	{ "last_dial",	"0,1",	0 },
 	{ NULL }
 };
 
@@ -101,14 +97,8 @@ void telephony_response_and_hold_req(void *telephony_device, int rh)
 	telephony_response_and_hold_rsp(telephony_device, CME_ERROR_NONE);
 }
 
-int telephony_last_dialed_number_req(void *telephony_device)
+void telephony_last_dialed_number_req(void *telephony_device)
 {
-	if( dummy_indicators[LAST_DIAL_INDEX].val == 0)
-	{
-		/* Since the Last dialed memory is Null Returning Error */
-		debug("last_dial number is null");
-		return 0;
-	}
 	telephony_last_dialed_number_rsp(telephony_device, CME_ERROR_NONE);
 
 	/* Notify outgoing call set-up successfully initiated */
@@ -119,8 +109,6 @@ int telephony_last_dialed_number_req(void *telephony_device)
 
 	active_call_status = CALL_STATUS_ALERTING;
 	active_call_dir = CALL_DIR_OUTGOING;
-	
-	return 1;
 }
 
 void telephony_terminate_call_req(void *telephony_device)
@@ -138,17 +126,6 @@ void telephony_terminate_call_req(void *telephony_device)
 						EV_CALL_INACTIVE);
 }
 
-void telephony_answer_outgoingcall_req(void *telephony_device)
-{
-
-        telephony_update_indicator(dummy_indicators, "call", EV_CALL_ACTIVE);
-        telephony_update_indicator(dummy_indicators, "callsetup",
-                                        EV_CALLSETUP_INACTIVE);
-
-        active_call_status = CALL_STATUS_ACTIVE;
-}
-
-
 void telephony_answer_call_req(void *telephony_device)
 {
 	telephony_answer_call_rsp(telephony_device, CME_ERROR_NONE);
@@ -160,18 +137,12 @@ void telephony_answer_call_req(void *telephony_device)
 	active_call_status = CALL_STATUS_ACTIVE;
 }
 
-int telephony_dial_number_req(void *telephony_device, const char *number)
+void telephony_dial_number_req(void *telephony_device, const char *number)
 {
 	g_free(active_call_number);
 	active_call_number = g_strdup(number);
 
-	debug("telephony-dummy: dial request to %s ,last-dial %d", active_call_number,dummy_indicators[LAST_DIAL_INDEX].val);
-	/*PTS Testcase:OCM Dial to mem or Index  in phonebook is invalid */
-	if(number[0] == '>' && dummy_indicators[LAST_DIAL_INDEX].val == 0)
-	{
-		debug("rejecting the dial request on wrong index");
-		return 0;
-	}
+	debug("telephony-dummy: dial request to %s", active_call_number);
 
 	telephony_dial_number_rsp(telephony_device, CME_ERROR_NONE);
 
@@ -183,8 +154,6 @@ int telephony_dial_number_req(void *telephony_device, const char *number)
 
 	active_call_status = CALL_STATUS_ALERTING;
 	active_call_dir = CALL_DIR_OUTGOING;
-
-	return 1;
 }
 
 void telephony_transmit_dtmf_req(void *telephony_device, char tone)
@@ -257,13 +226,12 @@ static DBusMessage *incoming_call(DBusConnection *conn, DBusMessage *msg,
 					void *data)
 {
 	const char *number;
-	dbus_uint32_t type_of_number;
 
 	if (!dbus_message_get_args(msg, NULL, DBUS_TYPE_STRING, &number,
-				DBUS_TYPE_UINT32, &type_of_number,DBUS_TYPE_INVALID))
+						DBUS_TYPE_INVALID))
 		return invalid_args(msg);
 
-	debug("telephony-dummy: incoming call to %s,type_of_number %d ", number,type_of_number);
+	debug("telephony-dummy: incoming call to %s", number);
 
 	g_free(active_call_number);
 	active_call_number = g_strdup(number);
@@ -274,28 +242,10 @@ static DBusMessage *incoming_call(DBusConnection *conn, DBusMessage *msg,
 	active_call_status = CALL_STATUS_INCOMING;
 	active_call_dir = CALL_DIR_INCOMING;
 
-	telephony_incoming_call_ind(number, type_of_number);
+	telephony_incoming_call_ind(number, 0);
 
 	return dbus_message_new_method_return(msg);
 }
-static DBusMessage *outgoing_call_answered(DBusConnection *conn, DBusMessage *msg,
-					void *data)
-{
-	debug("telephony-dummy: outgoing call was answered");
-
-	if (telephony_get_indicator(dummy_indicators, "callsetup") > 0) {
-		telephony_update_indicator(dummy_indicators, "callsetup",
-						EV_CALLSETUP_INACTIVE);
-		telephony_calling_stopped_ind();
-	}
-
-	if (telephony_get_indicator(dummy_indicators, "call") > 0)
-		telephony_update_indicator(dummy_indicators, "call",
-						EV_CALL_ACTIVE);
-
-	return dbus_message_new_method_return(msg);
-}
-
 
 static DBusMessage *cancel_call(DBusConnection *conn, DBusMessage *msg,
 					void *data)
@@ -375,25 +325,6 @@ static DBusMessage *roaming_status(DBusConnection *conn, DBusMessage *msg,
 	return dbus_message_new_method_return(msg);
 }
 
-static DBusMessage *last_dial_memory_status(DBusConnection *conn, DBusMessage *msg,
-					void *data)
-{
-	dbus_bool_t memory_status;
-	int val;
-
-	if (!dbus_message_get_args(msg, NULL, DBUS_TYPE_BOOLEAN, &memory_status,
-						DBUS_TYPE_INVALID))
-		return invalid_args(msg);
-
-	val = memory_status ? 1 : 0;
-
-	telephony_update_indicator(dummy_indicators, "last_dial", val);
-
-	debug("telephony-dummy: last_dial_memory_status status set to %d", val);
-
-	return dbus_message_new_method_return(msg);
-}
-
 static DBusMessage *registration_status(DBusConnection *conn, DBusMessage *msg,
 					void *data)
 {
@@ -431,33 +362,15 @@ static DBusMessage *set_subscriber_number(DBusConnection *conn,
 	return dbus_message_new_method_return(msg);
 }
 
-static DBusMessage *call_setup_status(DBusConnection *conn, DBusMessage *msg,
-					void *data)
-{
-	dbus_uint32_t call_status;
-	dbus_uint32_t callsetup_status;
-
-	if (!dbus_message_get_args(msg, NULL, DBUS_TYPE_UINT32, &call_status,
-				DBUS_TYPE_UINT32, &callsetup_status,DBUS_TYPE_INVALID))
-		return invalid_args(msg);
-
-	dummy_indicators[CALL_STATUS_INDEX].val = call_status;
-	dummy_indicators[CALL_SETUP_INDEX].val = callsetup_status;
-	return dbus_message_new_method_return(msg);
-}
-
 static GDBusMethodTable dummy_methods[] = {
 	{ "OutgoingCall",	"s",	"",	outgoing_call		},
-	{ "IncomingCall",	"su",	"",	incoming_call		},
+	{ "IncomingCall",	"s",	"",	incoming_call		},
 	{ "CancelCall",		"",	"",	cancel_call		},
-	{ "OutgoingCallAnswered",		"",	"",     outgoing_call_answered             },
 	{ "SignalStrength",	"u",	"",	signal_strength		},
 	{ "BatteryLevel",	"u",	"",	battery_level		},
 	{ "RoamingStatus",	"b",	"",	roaming_status		},
 	{ "RegistrationStatus",	"b",	"",	registration_status	},
 	{ "SetSubscriberNumber","s",	"",	set_subscriber_number	},
-	{ "LastDialMemoryStatus",	"b",	"",	last_dial_memory_status	},
-	{ "CallStatus",	"uu",	"",	call_setup_status	},
 	{ }
 };
 
