@@ -941,7 +941,7 @@ static void cmd_version(int ctl, int hdev, char *opt)
 		"\tManufacturer: %s (%d)\n",
 		hciver ? hciver : "n/a", ver.hci_ver, ver.hci_rev,
 		lmpver ? lmpver : "n/a", ver.lmp_ver, ver.lmp_subver,
-		bt_compidtostr(ver.err), ver.err);
+		bt_compidtostr(ver.manufacturer), ver.manufacturer);
 
 	if (hciver)
 		bt_free(hciver);
@@ -1540,7 +1540,7 @@ static void cmd_revision(int ctl, int hdev, char *opt)
 	}
 
 	print_dev_hdr(&di);
-	switch (ver.err) {
+	switch (ver.manufacturer) {
 	case 0:
 	case 37:
 	case 48:
